summaryrefslogtreecommitdiffstats
path: root/raul/Atom.h
diff options
context:
space:
mode:
Diffstat (limited to 'raul/Atom.h')
-rw-r--r--raul/Atom.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/raul/Atom.h b/raul/Atom.h
index 372cd78..3bfa68f 100644
--- a/raul/Atom.h
+++ b/raul/Atom.h
@@ -1,11 +1,11 @@
-/* This file is part of Ingen. Copyright (C) 2006 Dave Robillard.
+/* This file is part of Raul. Copyright (C) 2007 Dave Robillard.
*
* Ingen is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.
*
@@ -24,6 +24,8 @@
using std::string;
+namespace Raul {
+
/** An OSC atom (fundamental data types OSC messages are composed of).
*
@@ -126,4 +128,7 @@ private:
};
};
+
+} // namespace Raul
+
#endif // RAUL_ATOM_H
@@ -1,11 +1,11 @@
*
- * Ingen is free software; you can redistribute it and/or modify it under the
+ * Raul is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
@@ -1,11 +1,11 @@
* version.
*
- * Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Raul is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.